Crate rustmeter_beacon_target

Crate rustmeter_beacon_target 

Modules

core_id
monitors

Macros

get_static_id_by_registry
monitor_scoped
Macro to monitor a code scope with Rustmeter Beacon.
monitor_value
Macro to monitor a numeric value with Rustmeter Beacon.