Crate rustmeter_beacon_target
rustmeter_
beacon_
target
0.2.0
All Items
Crate Items
Modules
Macros
Crate
rustmeter_
beacon_
target
Modules

core_id
monitors
Macros

get_
static_
id_
by_
registry
monitor_
scoped
Macro to monitor a code scope with Rustmeter Beacon.
monitor_
value
Macro to monitor a numeric value with Rustmeter Beacon.